#
# spec file for package libEMF
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libEMF
Version:        1.0.13
Release:        3.7
Summary:        Library for Manipulation with Enhanced MetaFile (EMF, ECMA-234)
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://libemf.sourceforge.net/
Source:         https://downloads.sourceforge.net/libemf/libemf-%{version}.tar.gz
Patch1:         riscv64-support.patch
Patch2:         ppc64le-support.patch
BuildRequires:  gcc-c++
# taken from includes/wine/winnt.h
ExclusiveArch:  alpha %{arm} aarch64 %{ix86} mips ppc ppc64 ppc64le riscv64 sparc s390 s390x x86_64

%description
LibEMF is a C/C++ library that provides a drawing toolkit based on
ECMA-234. The general purpose of this library is to create vector
graphics files on POSIX systems that can be imported into StarOffice or
OpenOffice. The Enhanced MetaFile (EMF) is one of the two color vector
graphics format that is "vectorially" understood by SO and OO. The EMF
format also has the additional advantage that it can be "broken" into
its constituent components and edited like any other SO or OO graphics
object.

%package -n libEMF1
Summary:        Library for manipulation with Enhanced MetaFile (EMF, ECMA-234)
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libEMF1
LibEMF is a C/C++ library which provides a drawing toolkit based on
ECMA-234. The general purpose of this library is to create vector
graphics files on POSIX systems which can be imported into
StarOffice/OpenOffice. The Enhanced MetaFile (EMF) is one of the two
color vector graphics format which is "vectorially" understood by
SO/OO. The EMF format also has the additional advantage that it can be
"broken" into its constituent components and edited like any other
SO/OO graphics object.

%package utils
Summary:        Library for manipulation with Enhanced MetaFile (EMF, ECMA-234)
# split-provides for upgrade from openSUSE <= 12.1 and SLE <= 11
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
Provides:       %{name}:%{_bindir}/printemf

%description utils
LibEMF is a C/C++ library which provides a drawing toolkit based on
ECMA-234. The general purpose of this library is to create vector
graphics files on POSIX systems which can be imported into
StarOffice/OpenOffice. The Enhanced MetaFile (EMF) is one of the two
color vector graphics format which is "vectorially" understood by
SO/OO. The EMF format also has the additional advantage that it can be
"broken" into its constituent components and edited like any other
SO/OO graphics object.

%package devel
Summary:        Library for manipulation with Enhanced MetaFile (EMF, ECMA-234)
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libEMF1 = %{version}

%description devel
LibEMF is a C/C++ library which provides a drawing toolkit based on
ECMA-234. The general purpose of this library is to create vector
graphics files on POSIX systems which can be imported into
StarOffice/OpenOffice. The Enhanced MetaFile (EMF) is one of the two
color vector graphics format which is "vectorially" understood by
SO/OO. The EMF format also has the additional advantage that it can be
"broken" into its constituent components and edited like any other
SO/OO graphics object.

%prep
%autosetup -p1 -n libemf-%{version}

%build
%configure\
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n libEMF1 -p /sbin/ldconfig
%postun -n libEMF1 -p /sbin/ldconfig

%files -n libEMF1
%license COPYING.LIB
%{_libdir}/*.so.*

%files utils
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/*

%files devel
%doc doc/html
%{_includedir}/libEMF
%{_libdir}/*.so

%changelog
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- add riscv64-support.patch
- enable build for riscv64
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.0.13:
  * CVE-2020-13999 (bsc#1173070)
  libEMF (aka ECMA-234 Metafile Library) through 1.0.12 is vulnerable to
  Integer overflow condition in libemf.cpp:ScaleviewportExtEx function
  leading to Denial of Service
  VulnerabilityType : Integer Overflow
* Wed May 27 2020 Jason Sikes <jsikes@suse.com>
- Upgrade to version 1.0.12
  * Fixes for CVE-2020-11863, CVE-2020-11864,
    CVE-2020-11865, and CVE-2020-11866.
  * bsc#1171496, bsc#1171497, bsc#1171498, and  bsc#1171499
  * Removed obsoleted aarch64-support.patch
* Fri Sep  4 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Enable build checks
* Mon Dec  9 2013 uweigand@de.ibm.com
- ppc64le-support.patch: Support for powerpc64le
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Mar 20 2013 schwab@suse.de
- aarch64-support.patch: Support for aarch64
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Wed Nov  7 2012 sbrabec@suse.cz
- Upgrade to version 1.0.7:
  * Fixes and additions for various non-x86 architectures.
* Mon Aug 20 2012 agraf@suse.com
- add support for arm
* Mon Jun  4 2012 dmueller@suse.com
- exclude from arm (does not build there)
* Fri May 25 2012 sbrabec@suse.cz
- Upgrade to version 1.0.6:
  * Added support for strokeandfillpath and setmiterlimit.
  * Minor fixes.
- Build for all architectures.
- Split according to the Shared Library Packaging Policy.
* Wed Mar  4 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Aug 13 2008 ro@suse.de
- move ExclusiveArch to main package
* Fri Feb 29 2008 ro@suse.de
- fix build with current gcc
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Sat Aug 23 2003 ro@suse.de
- added ExclusiveArch to specfile
* Sun Jun 15 2003 coolo@suse.de
- package %%_docdir
* Thu Nov 21 2002 sbrabec@suse.cz
- New package.
